/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

float4x4 g_worldViewProj;

struct VertexShaderInput
{
    float4 Position : POSITION0;
	float3 Normal : NORMAL0;
};

struct VertexShaderOutput
{
    float4 Position : POSITION0;
	float3 Normal : TEXCOORD0;
};

struct PixelShaderInput
{
	float3 Normal : TEXCOORD0;
};

VertexShaderOutput VertexShaderFunction(VertexShaderInput input)
{
    VertexShaderOutput output;

   	output.Normal = (mul(float4(input.Normal, 0.0f), g_worldViewProj).xyz / 2.0f) + 0.5f;
    output.Position = mul(input.Position, g_worldViewProj);

    return output;
}

float4 PixelShaderFunction(PixelShaderInput input) : COLOR0
{
	float3 normal = normalize((input.Normal - 0.5f) * 2.0f);
	float light = saturate(0.4f + (0.6f * dot(normal, float3(0.0f, 0.0f, -1.0f))));
	return float4(0.0f, light, 0.0f, 1.0f);
}

technique Technique1
{
    pass P1
    {
        VertexShader = compile vs_2_0 VertexShaderFunction();
        PixelShader = compile ps_2_0 PixelShaderFunction();
    }
}