/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;

namespace BoxEdit3D
{
    /// <summary>
    /// This class is a derived class of the command class. It handles
    /// the box creation. An instance of this class will be issued for
    /// every box that will be created in the scene. This class is part
    /// of the command design pattern published by Gamma et. al.
    /// </summary>
    class CreateCommand : Command
    {
        /// <summary>
        /// The scene to which the box will be added.
        /// </summary>
        private Scene m_scene;

        /// <summary>
        /// The number of the box that was selected previous to the creation of the new box.
        /// </summary>
        private int m_previousSelectedBox;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="box">The box on which this command will be executed.</param>
        /// <param name="scene">The scene to which the box will be added.</param>
        public CreateCommand(Box box, Scene scene)
            : base(box)
        {
            m_scene = scene;
            m_previousSelectedBox = m_scene.getSelectedBoxNumber();
        }

        /// <summary>
        /// Execute the command on the box.
        /// </summary>
        public override void execute()
        {
            m_scene.addBox(m_box);
        }

        /// <summary>
        /// Undo the execution of the command on the box.
        /// </summary>
        public override void unexecute()
        {
            m_scene.removeBox(m_box);
            m_scene.selectBox(m_previousSelectedBox);
        }
    }
}
