/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Content;

namespace BoxEdit3D
{
    /// <summary>
    /// This Dummy gizmo does not do anything. It is used in the UserInput
    /// class when the NoGizmo Mode is activated.
    /// </summary>
    class DummyGizmo : Gizmo
    {
        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="graphics">Needed to initialize the base class.</param>
        public DummyGizmo(GraphicsDeviceManager graphics)
            : base(graphics)
        {
        }

        /// <summary>
        /// Doesn't do anything.
        /// </summary>
        /// <param name="viewProj">The ViewProjection Matrix.</param>
        public override void render(Matrix viewProj)
        {
        }

        /// <summary>
        /// Doesn't do anything.
        /// </summary>
        public override void lostFocus()
        {
            discardDrag();
            base.lostFocus();
        }

        /// <summary>
        /// Returns the value 0.
        /// </summary>
        /// <returns>Always returns 0</returns>
        public override int getNumberOfGizmoParts()
        {
            return 0;
        }

        /// <summary>
        /// Doesn't do anything.
        /// </summary>
        /// <param name="index">The index of the gizmo part.</param>
        /// <returns>Always returns null, as the DummyGizmo has no gizmo parts.</returns>
        public override Model getGizmoPart(int index)
        {
            return null;
        }

        /// <summary>
        /// Doesn't do anything.
        /// </summary>
        /// <param name="gizmoPart">The index of the gizmo part.</param>
        public override void startDrag(int gizmoPart)
        {            
        }

        /// <summary>
        /// Doesn't do anything.
        /// </summary>
        /// <returns>Always returns null.</returns>
        public override Command applyDrag()
        {
            return null;
        }

        /// <summary>
        /// Doesn't do anything.
        /// </summary>
        public override void discardDrag()
        {
        }

        /// <summary>
        /// Doesn't do anything.
        /// </summary>
        public override void handleMouseInput(Matrix viewProjectionMatrix)
        {
        }
    }
}
