/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;

namespace BoxEdit3D
{
    /// <summary>
    /// This class is a derived class of the command class. It handles
    /// the scaling of boxes. An instance of this class will be issued
    /// every time a box is scaled. This class is part of the command 
    /// design pattern published by Gamma et. al.
    /// </summary>
    class ScaleCommand : Command
    {
        /// <summary>
        /// The scale that will be applied by the ScaleCommand.
        /// </summary>
        private Vector3 m_scale;

        /// <summary>
        /// The absolute scale of the box before it was scaled by this ScaleCommand.
        /// </summary>
        private Vector3 m_oldScale;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="box">The box on which this command will be executed.</param>
        /// <param name="scale">The scale that will be applied to the box.</param>
        public ScaleCommand(Box box, Vector3 scale)
            : base(box)
        {
            m_scale = scale;
            m_oldScale = m_box.getScale();
        }

        /// <summary>
        /// Execute the command on the box.
        /// </summary>
        public override void execute()
        {
            m_box.setScale(m_scale);
        }

        /// <summary>
        /// Undo the execution of the command on the box.
        /// </summary>
        public override void unexecute()
        {
            m_box.setScale(m_oldScale);
        }
    }
}
