/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;

namespace BoxEdit3D
{
    /// <summary>
    /// This class is a derived class of the command class. It handles
    /// changes to the used texture of a box. An instance of this class
    /// will be issued every time a new texture is applied to a box.
    /// This class is part of the command design pattern published by
    /// Gamma et. al.
    /// </summary>
    class TextureCommand : Command
    {
        /// <summary>
        /// The filename of the texture that will be applied by the TextureCommand.
        /// </summary>
        private string m_newPath;

        /// <summary>
        /// The filename of the texture that will be used if this command is reversed.
        /// </summary>
        private string m_oldPath;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="box">The box on which this command will be executed.</param>
        /// <param name="filename">The filename of the new texture that will be applied to the box.</param>
        public TextureCommand(Box box, string filename)
            : base(box)
        {
            m_newPath = filename;
            m_oldPath = box.getTextureFilename();
        }

        /// <summary>
        /// Execute the command on the box.
        /// </summary>
        public override void execute()
        {
            m_box.setTextureFilename(m_newPath);
        }

        /// <summary>
        /// Undo the execution of the command on the box.
        /// </summary>
        public override void unexecute()
        {
            m_box.setTextureFilename(m_oldPath);
        }
    }
}
