/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;

namespace BoxEdit3D
{
    /// <summary>
    /// This class can hold the internal information of Box class so that
    /// the XMLSerialization can be used. This class is used as a kind of
    /// memento design pattern to the box class. As C# does not support the
    /// friend construct, the access cannot only be granted to a single
    /// defined class.
    /// </summary>
    public class XMLBox
    {
        // internal variables to hold the position, scale and rotation
        private Vector3 m_translation = Vector3.Zero;
        private Vector3 m_scale = Vector3.One;
        private Quaternion m_rotation = Quaternion.Identity;
        private string m_texturePath = "";

        /// <summary>
        /// Accessor methods to expose the internal translation variable.
        /// </summary>
        public Vector3 translation
        {
            get
            {
                return m_translation;
            }
            set
            {
                m_translation = value;
            }
        }

        /// <summary>
        /// Accessor methods to expose the internal scale variable.
        /// </summary>
        public Vector3 scale
        {
            get
            {
                return m_scale;
            }
            set
            {
                m_scale = value;
            }
        }

        /// <summary>
        /// Accessor methods to expose the internal rotation variable.
        /// </summary>
        public Quaternion rotation
        {
            get
            {
                return m_rotation;
            }
            set
            {
                m_rotation = value;
            }
        }

        /// <summary>
        /// Accessor methods to expose the internal texture path variable.
        /// </summary>
        public string texturePath
        {
            get
            {
                return m_texturePath;
            }
            set
            {
                m_texturePath = value;
            }
        }
    }
}
